%define name LPRng
%define version 3.6.12
%define release 2mdk

Summary: LPRng Print Spooler for UNIX and NT
Name: %{name}
Version: %{version}
Release: %{release}
Copyright: OpenSource
Group: System/Configuration/Printing
Source: %{name}-%{version}.tar.bz2
Patch:	LPRng-patch.bz2
URL: http://www.astart.com/LPRng.html
Buildroot: /var/tmp/%{name}-buildroot
Packager: Patrick Powell <papowell@astart.com>

%description
The LPRng software is an enhanced, extended, and portable implementation
of the Berkeley LPR print spooler functionality. While providing the
same interface and meeting RFC1179 requirements, the implementation
is completely new and provides support for the following features:
lightweight (no databases needed) lpr, lpc, and lprm programs; dynamic
redirection of print queues; automatic job holding; highly verbose
diagnostics; multiple printers serving a single queue; client programs
do not need to run SUID root; greatly enhanced security checks; and a
greatly improved permission and authorization mechanism.

The source software compiles and runs on a wide variety of UNIX systems,
and is compatible with other print spoolers and network printers that
use the LPR interface and meet RFC1179 requirements.  LPRng provides
emulation packages for the SVR4 lp and lpstat programs, eliminating the
need for another print spooler package. These emulation packages can be
modified according to local requirements, in order to support vintage
printing systems.  An NT version is also available.

For users that require secure and/or authenticated printing support,
LPRng supports Kerberos V, MIT Kerberos IV Print Support, and PGP
authentication.  LPRng is being adopted by MIT for use as their Campus
Wide printing support system. Additional authentication support is
extremely simple to add.  LPRng is Open Source Software, and the current
public distribution is available from the listed FTP and Web Sites.

%changelog
* Wed Apr 19 2000 Lenny Cartier <lenny@mandrakesoft.com> 3.6.12-2mdk
- bz2 patch
- fix group
* Wed Feb 16 2000 Stefan van der Eijk <s.vandereijk@chello.nl>
  - made patch so users can build the package
  - altered .spec file --> checkconfig for redhat / mandrake
* Mon Sep 13 1999 Patrick Powell <papowell@astart.com>
  - resolved problems with symbolic links to /etc/init.d
    files - used the chkconfig facility
* Sat Sep  4 1999 Patrick Powell <papowell@astart.com>
  - did ugly things to put the script in the spec file
* Sat Aug 28 1999 Giulio Orsero <giulioo@tiscalinet.it>
  - 3.6.8
* Fri Aug 27 1999 Giulio Orsero <giulioo@tiscalinet.it>
  - 3.6.7 First RPM build.
  
%prep
%setup
%patch
%build
CFLAGS=$RPM_OPT_FLAGS  ./configure --prefix=/usr --sysconfdir=/etc
make 

# clean docs	
cd $RPM_BUILD_DIR/%{name}-%{version}/HOWTO;
gzip -9 LPRng-HOWTO.txt LPRng-HOWTO.ps

%install

rm -rf $RPM_BUILD_ROOT

# ---- WARNING ---- READ THIS BEFORE YOU MODIFY THE SCRIPT
# The next section creates the lpd startup/shutdown script.
# This exposes one of the weaknesses in the RPM specfile -
# it may not be self contained and may needs other support files.
#  Patrick Powell <papowell@astart.com>
#######

cat <<'EOF' >/tmp/lpd
#!/bin/sh
#
# lpd           This shell script takes care of starting and stopping
#               lpd (printer daemon).
#
# chkconfig: 2345 60 60
# description: lpd is the print daemon required for lpr to work properly. \
#   It is basically a server that arbitrates print jobs to printer(s).
# processname: lpd
# config: /etc/printcap

# Source function library.
. /etc/rc.d/init.d/functions

# Source networking configuration.
. /etc/sysconfig/network

# Check that networking is up.
[ ${NETWORKING} = "no" ] && exit 0

[ -f /usr/sbin/lpd ] || exit 0

[ -f /etc/printcap ] || exit 0

# See how we were called.
case "$1" in
  start)
        # Start daemons.
        echo -n "Starting lpd: "
        daemon lpd
        echo
        touch /var/lock/subsys/lpd
        ;;
  stop)
        # Stop daemons.
        echo -n "Shutting down lpd: "
	killproc lpd
        echo
        rm -f /var/lock/subsys/lpd
        ;;
  status)
	status lpd
	;;
  restart|reload)
	$0 stop
	$0 start
	;;
  *)
        echo "Usage: lpd {start|stop|restart|reload|status}"
        exit 1
esac

exit 0
EOF


mkdir -p $RPM_BUILD_ROOT/etc/rc.d/init.d
mkdir -p $RPM_BUILD_ROOT/etc/rc.d/rc0.d
mkdir -p $RPM_BUILD_ROOT/etc/rc.d/rc1.d
mkdir -p $RPM_BUILD_ROOT/etc/rc.d/rc2.d
mkdir -p $RPM_BUILD_ROOT/etc/rc.d/rc3.d
mkdir -p $RPM_BUILD_ROOT/etc/rc.d/rc4.d
mkdir -p $RPM_BUILD_ROOT/etc/rc.d/rc5.d
mkdir -p $RPM_BUILD_ROOT/etc/rc.d/rc6.d
make install prefix=$RPM_BUILD_ROOT/usr sysconfdir=$RPM_BUILD_ROOT/etc

ln -s ../init.d/lpd $RPM_BUILD_ROOT/etc/rc.d/rc0.d/K60lpd
ln -s ../init.d/lpd $RPM_BUILD_ROOT/etc/rc.d/rc1.d/K60lpd
ln -s ../init.d/lpd $RPM_BUILD_ROOT/etc/rc.d/rc2.d/S60lpd
ln -s ../init.d/lpd $RPM_BUILD_ROOT/etc/rc.d/rc3.d/S60lpd
ln -s ../init.d/lpd $RPM_BUILD_ROOT/etc/rc.d/rc4.d/S60lpd
ln -s ../init.d/lpd $RPM_BUILD_ROOT/etc/rc.d/rc5.d/S60lpd
ln -s ../init.d/lpd $RPM_BUILD_ROOT/etc/rc.d/rc6.d/K60lpd

# rhl init script
install -m 755 /tmp/lpd $RPM_BUILD_ROOT/etc/rc.d/init.d/lpd
find $RPM_BUILD_ROOT/usr/man -name "*.gz" -exec gunzip {} \;
find $RPM_BUILD_ROOT/usr/man -type f -exec bzip2 -9f {} \;

%clean
rm -rf $RPM_BUILD_ROOT

%pre
if test -x /etc/rc.d/init.d/lpd
  then /etc/rc.d/init.d/lpd stop 1>/dev/null 2>&1
fi

%post
# for RedHat
/sbin/chkconfig --add lpd

%preun
if test "$1" = 0
then
  if test -x /etc/rc.d/init.d/lpd
  then
    /etc/rc.d/init.d/lpd stop 1>/dev/null 2>&1
  fi
# for RedHat
/sbin/chkconfig --del lpd
fi

%files
%defattr(-,root,root)
%attr(644,root,root) %config(noreplace) /etc/lpd.conf
%attr(644,root,root) %config(noreplace) /etc/lpd.perms
%defattr(-,root,root)
%attr(755,root,root) %config            /etc/rc.d/init.d/lpd
%attr(755,root,root) %config(missingok) /etc/rc.d/rc*.d/*lpd
%config %attr(644,root,root) /etc/lpd.conf.sample
%config %attr(644,root,root) /etc/lpd.perms.sample
%doc ABOUT-NLS.LPRng ANNOUNCE CHANGES CONTRIBUTORS COPYRIGHT INSTALL LICENSE 
%doc README* VERSION Y2KCompliance
%doc HOWTO/*.html HOWTO/*.gif HOWTO/*.gz HOWTO/*.info
%attr(4755,root,root) /usr/bin/lpq
%attr(4755,root,root) /usr/bin/lprm
%attr(4755,root,root) /usr/bin/lpr
%attr(4755,root,root) /usr/bin/lpstat
/usr/bin/lp
/usr/bin/cancel
%attr(4755,root,root) /usr/sbin/lpc
%attr(755,root,root)  /usr/sbin/lpd
%attr(755,root,root)  /usr/sbin/checkpc
%attr(755,root,root)  /usr/sbin/lpraccnt
%attr(755,root,root)  /usr/libexec/filters/*
/usr/man/*/*
